Module proxy

Module proxy 

Modules

netfilter
tenant_resolver
transparent

Structs

ProxyServer

Enums

ProxyError
Custom error type for proxy operations

Functions

build_server_tls_for_host
Build a TLS server configuration for the given host using the CA
client
Create a configured reqwest client for upstream requests
convert_boxbody_to_full_response
Convert a Response<BoxBody<Bytes, ErrorCode>> to a Response<Full>
convert_hyper_incoming_to_reqwest_request
Convert a hyper Request to a reqwest Request
convert_reqwest_to_hyper_response
Convert a reqwest Response to a hyper Response with streaming body
is_closed
Check if an error indicates a closed connection
parse_authority_host_port
Parse authority string into host and port components
strip_proxy_headers
Strip hop-by-hop headers from HTTP requests/responses

Type Aliases

ProxyResult
UpstreamClient