Module cel
witmproxy
0.0.6
Module cel
Module Items
Structs
In witmproxy::
plugins
witmproxy
::
plugins
Module
cel
Structs

CelConnect
CelContent
CelRequest
CelResponse
CelTime
A CEL context object providing time-based convenience methods for controlling when a plugin should run, without leaking detailed host information to the plugin.