Modules
Structs
Enums
- Proxy
Error - Custom error type for proxy operations
Functions
- build_
server_ tls_ for_ host - Build a TLS server configuration for the given host using the CA
- client
- Create a configured reqwest client for upstream requests
- convert_
boxbody_ to_ full_ response - Convert a Response<BoxBody<Bytes, ErrorCode>> to a Response<Full
> - convert_
hyper_ incoming_ to_ reqwest_ request - Convert a hyper Request to a reqwest Request
- convert_
reqwest_ to_ hyper_ response - Convert a reqwest Response to a hyper Response with streaming body
- is_
closed - Check if an error indicates a closed connection
- parse_
authority_ host_ port - Parse authority string into host and port components
- strip_
proxy_ headers - Strip hop-by-hop headers from HTTP requests/responses